=======================
Spatiotemporal analysis
=======================

.. autoclass:: pylandstats.SpatioTemporalAnalysis
   :members: __init__, compute_class_metrics_df, compute_landscape_metrics_df, plot_metric, plot_landscapes
